@@ -1,4 +1,6 @@
 from .data_parsers.htc_vive_pro_data import HtcViveProData
+from .data_parsers.pico_neo_data import PicoNeoData
+from .data_parsers.pupil_invisible_data import PupilInvisibleData
 from .data_parsers.reduced_data import ReducedData
 from .error_type import ErrorType
 from .identification.gaze_behavior_identifier import GazeBehaviorIdentifier
@@ -8,6 +10,8 @@ from .version import __version__
 
 __all__ = [
     "HtcViveProData",
+    "PicoNeoData",
+    "PupilInvisibleData",
     "ReducedData",
     "ErrorType",
     "GazeBehaviorIdentifier",
