@@ -43,6 +43,7 @@ def perform_one_file(
     gaze_behavior_identifier.detect_invalid_sequences()
     gaze_behavior_identifier.detect_saccade_sequences(
         min_acceleration_threshold=4000,
+        nb_acceleration_frames=2,
         velocity_window_size=0.52,
         velocity_factor=5.0,
     )
@@ -335,13 +336,13 @@ def test_original_code():
         print(file_name)
 
         if file_name == "TESTNA01_2D_Fist3":
-            assert captured_output.getvalue() == r"Smooth pursuit : 1.24122 s ----"
+            assert captured_output.getvalue() == r"Smooth pursuit : 0.33311 s ----"
         elif file_name == "TESTNA01_360VR_Fist3":
             assert captured_output.getvalue() == ""
         elif file_name == "TESTNA05_2D_Spread7":
-            assert captured_output.getvalue() == "Fixation : 0.942 s ----"
+            assert captured_output.getvalue() == "Fixation : 0.64128 s ----"
         elif file_name == "TESTNA05_360VR_Spread7":
-            assert captured_output.getvalue() == "Smooth pursuit : 0.51662 s ----"
+            assert captured_output.getvalue() == "Smooth pursuit : 0.55851 s ----"
         elif file_name == "TESTNA15_2D_Pen3":
             assert captured_output.getvalue() == "Fixation : 0.20745 s ----"
         elif file_name == "TESTNA15_360VR_Pen3":
@@ -363,8 +364,3 @@ def test_original_code():
                 output_reference = pickle.load(result_file)
 
             pdt.assert_frame_equal(output, output_reference, check_exact=False, rtol=1e-5)
-
-
-"""
-TODO: test the plots pixels
-"""
